@@ -176,8 +176,7 @@ pub fn solve(
         (2018, 13, 2) => to_stringer(year2018::day13::part2, input_string),
         (2018, 14, 1) => to_stringer(year2018::day14::part1, input_string),
         (2018, 14, 2) => to_stringer(year2018::day14::part2, input_string),
-        (2018, 15, 1) => to_stringer(year2018::day15::part1, input_string),
-        (2018, 15, 2) => to_stringer(year2018::day15::part2, input_string),
+        (2018, 15, _) => to_stringer_input(year2018::day15::solve, &mut input),
         (2018, 16, 1) => to_stringer(year2018::day16::part1, input_string),
         (2018, 16, 2) => to_stringer(year2018::day16::part2, input_string),
         (2018, 17, _) => to_stringer_input(year2018::day17::solve, &mut input),
@@ -196,10 +195,8 @@ pub fn solve(
         (2018, 24, 2) => to_stringer(year2018::day24::part2, input_string),
         (2018, 25, 1) => to_stringer(year2018::day25::part1, input_string),
         (2018, 25, 2) => to_stringer(year2018::day25::part2, input_string),
-        (2019, 1, 1) => to_stringer(year2019::day01::part1, input_string),
-        (2019, 1, 2) => to_stringer(year2019::day01::part2, input_string),
-        (2019, 2, 1) => to_stringer(year2019::day02::part1, input_string),
-        (2019, 2, 2) => to_stringer(year2019::day02::part2, input_string),
+        (2019, 1, _) => to_stringer_input(year2019::day01::solve, &mut input),
+        (2019, 2, _) => to_stringer_input(year2019::day02::solve, &mut input),
         (2019, 3, _) => to_stringer_input(year2019::day03::solve, &mut input),
         (2019, 4, _) => to_stringer_input(year2019::day04::solve, &mut input),
         (2019, 5, 1) => to_stringer(year2019::day05::part1, input_string),
